@@ -1,16 +1,18 @@
-import os.path
-
-from collections import OrderedDict
-from pathlib import Path
+import collections
+import pathlib
 
 from . import abc
 
 from ._compat import ZipPath
 
 
+def remove_duplicates(items):
+    return iter(collections.OrderedDict.fromkeys(items))
+
+
 class FileReader(abc.TraversableResources):
     def __init__(self, loader):
-        self.path = Path(loader.path).parent
+        self.path = pathlib.Path(loader.path).parent
 
     def resource_path(self, resource):
         """
@@ -53,15 +55,14 @@ class MultiplexedPath(abc.Traversable):
     namespace packages which may be multihomed at a single
     name.
     """
+
     def __init__(self, *paths):
-        paths = list(OrderedDict.fromkeys(paths))  # remove duplicates
-        self._paths = list(map(Path, paths))
+        self._paths = list(map(pathlib.Path, remove_duplicates(paths)))
         if not self._paths:
             message = 'MultiplexedPath must contain at least one path'
             raise FileNotFoundError(message)
-        if any(not path.is_dir() for path in self._paths):
-            raise NotADirectoryError(
-                'MultiplexedPath only supports directories')
+        if not all(path.is_dir() for path in self._paths):
+            raise NotADirectoryError('MultiplexedPath only supports directories')
 
     def iterdir(self):
         visited = []
@@ -73,10 +74,10 @@ class MultiplexedPath(abc.Traversable):
                 yield file
 
     def read_bytes(self):
-        raise FileNotFoundError('{} is not a file'.format(self))
+        raise FileNotFoundError(f'{self} is not a file')
 
     def read_text(self, *args, **kwargs):
-        raise FileNotFoundError('{} is not a file'.format(self))
+        raise FileNotFoundError(f'{self} is not a file')
 
     def is_dir(self):
         return True
@@ -97,12 +98,14 @@ class MultiplexedPath(abc.Traversable):
     def open(self, *args, **kwargs):
         raise FileNotFoundError('{} is not a file'.format(self))
 
+    @property
     def name(self):
-        return os.path.basename(self._paths[0])
+        return self._paths[0].name
 
     def __repr__(self):
         return 'MultiplexedPath({})'.format(
-            ', '.join("'{}'".format(path) for path in self._paths))
+            ', '.join("'{}'".format(path) for path in self._paths)
+        )
 
 
 class NamespaceReader(abc.TraversableResources):
